pilas.grupo.Grupo

Package pilas :: Module grupo :: Class Grupo |
[hide private]
[frames] | no frames]

# Class Grupo

source code

    object --+
             |
          list --+
                 |
                Grupo

Un grupo es un contenedor que funciona como una lista normal, pero mejorada.

Los grupos pueden contener actores, y permite que a todos los actores se los pueda tratar como uno.

Por ejemplo si tienes un contenedor con 20 actores, podrías ampliar el tamaño de todos ellos juntos usando la sentencia:

    >>> grupo = pilas.atajos.fabricar(pilas.actores.Mono, 20)
    >>> grupo.escala = 2

Instance Methods | [hide private]
__getattr__(self, attr) Esta funcion se asegura de que cada vez que se invoque a un metodo del grupo, en realidad, el grupo va a invocar a ese metodo pero en todos sus elementos. | source code
__setattr__(self, atributo, valor) x.__setattr__('name', value) <==> x.name = value | source code
desordenar(self) Les asigna una posición aleatoria a todos los actores del grupo. | source code
limpiar(self) Elimina a todos los actores dentro del grupo. | source code
Inherited from `list`: `__add__`, `__contains__`, `__delitem__`, `__delslice__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__gt__`, `__iadd__`, `__imul__`, `__init__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__new__`, `__repr__`, `__reversed__`, `__rmul__`, `__setitem__`, `__setslice__`, `__sizeof__`, `append`, `count`, `extend`, `index`, `insert`, `pop`, `remove`, `reverse`, `sort` Inherited from `object`: `__delattr__`, `__format__`, `__reduce__`, `__reduce_ex__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `list`: `__hash__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __getattr__(self, attr) (Qualification operator) | source code
Esta funcion se asegura de que cada vez que se invoque a un metodo del grupo, en realidad, el grupo va a invocar a ese metodo pero en todos sus elementos. Algo asi como un map.

### __setattr__(self, atributo, valor) | source code
x.__setattr__('name', value) <==> x.name = value Overrides: object.__setattr__ (inherited documentation)